@@ -23,7 +23,7 @@ class QuickbooksCore(SitesCore):
     def send_message_service_type_not_found(self, manager: str, customer_or_service: str) -> None:
         pass
 
-    def send_message_invoice_added(self, manager: str, customer: str, invoice_number: str, amount: str) -> None:
+    def send_message_invoice_added(self, manager: str, customer: str, invoice_number: str, total_rate: str) -> None:
         pass
 
     def login_to_site(self) -> bool:
